@@ -3,8 +3,9 @@ Main interface for comprehend service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.comprehend import (
+    from mypy_boto3_comprehend import (
         Client,
         ComprehendClient,
         ListDocumentClassificationJobsPaginator,
@@ -15,7 +16,7 @@ Usage::
         ListKeyPhrasesDetectionJobsPaginator,
         ListSentimentDetectionJobsPaginator,
         ListTopicsDetectionJobsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -30,8 +31,9 @@ Usage::
     list_key_phrases_detection_jobs_paginator: ListKeyPhrasesDetectionJobsPaginator = client.get_paginator("list_key_phrases_detection_jobs")
     list_sentiment_detection_jobs_paginator: ListSentimentDetectionJobsPaginator = client.get_paginator("list_sentiment_detection_jobs")
     list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
+    ```
 """
-from mypy_boto3_comprehend.client import ComprehendClient as Client, ComprehendClient
+from mypy_boto3_comprehend.client import ComprehendClient, ComprehendClient as Client
 from mypy_boto3_comprehend.paginator import (
     ListDocumentClassificationJobsPaginator,
     ListDocumentClassifiersPaginator,
