@@ -3,8 +3,11 @@ Main interface for comprehend service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.comprehend import (
+
+    from mypy_boto3_comprehend import ComprehendClient
+    from mypy_boto3_comprehend import (
         ListDocumentClassificationJobsPaginator,
         ListDocumentClassifiersPaginator,
         ListDominantLanguageDetectionJobsPaginator,
@@ -25,6 +28,7 @@ Usage::
     list_key_phrases_detection_jobs_paginator: ListKeyPhrasesDetectionJobsPaginator = client.get_paginator("list_key_phrases_detection_jobs")
     list_sentiment_detection_jobs_paginator: ListSentimentDetectionJobsPaginator = client.get_paginator("list_sentiment_detection_jobs")
     list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -64,7 +68,7 @@ __all__ = (
 
 class ListDocumentClassificationJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
+    [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
     """
 
     def paginate(
@@ -73,13 +77,13 @@ class ListDocumentClassificationJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDocumentClassificationJobsResponseTypeDef]:
         """
-        [ListDocumentClassificationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
+        [ListDocumentClassificationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
         """
 
 
 class ListDocumentClassifiersPaginator(Boto3Paginator):
     """
-    [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
+    [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
     """
 
     def paginate(
@@ -88,13 +92,13 @@ class ListDocumentClassifiersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDocumentClassifiersResponseTypeDef]:
         """
-        [ListDocumentClassifiers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
+        [ListDocumentClassifiers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
         """
 
 
 class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
+    [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
     """
 
     def paginate(
@@ -103,13 +107,13 @@ class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDominantLanguageDetectionJobsResponseTypeDef]:
         """
-        [ListDominantLanguageDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
+        [ListDominantLanguageDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
         """
 
 
 class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
+    [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
     """
 
     def paginate(
@@ -118,13 +122,13 @@ class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEntitiesDetectionJobsResponseTypeDef]:
         """
-        [ListEntitiesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
+        [ListEntitiesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
         """
 
 
 class ListEntityRecognizersPaginator(Boto3Paginator):
     """
-    [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
+    [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
     """
 
     def paginate(
@@ -133,13 +137,13 @@ class ListEntityRecognizersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEntityRecognizersResponseTypeDef]:
         """
-        [ListEntityRecognizers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
+        [ListEntityRecognizers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
         """
 
 
 class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
+    [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
     """
 
     def paginate(
@@ -148,13 +152,13 @@ class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListKeyPhrasesDetectionJobsResponseTypeDef]:
         """
-        [ListKeyPhrasesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
+        [ListKeyPhrasesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
         """
 
 
 class ListSentimentDetectionJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
+    [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
     """
 
     def paginate(
@@ -163,13 +167,13 @@ class ListSentimentDetectionJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSentimentDetectionJobsResponseTypeDef]:
         """
-        [ListSentimentDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
+        [ListSentimentDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
         """
 
 
 class ListTopicsDetectionJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
+    [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
     """
 
     def paginate(
@@ -178,5 +182,5 @@ class ListTopicsDetectionJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTopicsDetectionJobsResponseTypeDef]:
         """
-        [ListTopicsDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
+        [ListTopicsDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
         """
