@@ -3,9 +3,11 @@ Main interface for comprehend service type definitions.
 
 Usage::
 
-    from mypy_boto3.comprehend.type_defs import BatchDetectDominantLanguageItemResultTypeDef
+    ```python
+    from mypy_boto3_comprehend.type_defs import BatchDetectDominantLanguageItemResultTypeDef
 
     data: BatchDetectDominantLanguageItemResultTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
